==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ListPanelItemModelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelItemModelDescription } from "./ListPanelItemModelDescription";
/**
 * @hidden
 */
export let ListPanelItemModelDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelItemModelDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelItemModelDescriptionMetadata.a == null) {
                ListPanelItemModelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelItemModelDescriptionMetadata.c(ListPanelItemModelDescriptionMetadata.a);
            }
            if (a.j(ListPanelItemModelDescriptionMetadata.a)) {
                return;
            }
            a.y(ListPanelItemModelDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DataRow", "Number:int");
            a.item("RowHeight", "Number:double");
            a.item("RowObjectRef", "(w:RowObject,wf:RowObject)DataRef");
            a.item("IsModelDirty", "Boolean");
        }
        static d(a) {
            ListPanelItemModelDescriptionMetadata.b(a);
            a.aa("ListPanelItemModel", () => new ListPanelItemModelDescription());
            a.z("ListPanelItemModel", ListPanelItemModelDescriptionMetadata.a);
        }
    }
    ListPanelItemModelDescriptionMetadata.$t = /*@__PURE__*/ markType(ListPanelItemModelDescriptionMetadata, 'ListPanelItemModelDescriptionMetadata');
    ListPanelItemModelDescriptionMetadata.a = null;
    return ListPanelItemModelDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ListPanelItemModelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelItemModelDescription } from "./ListPanelItemModelDescription";
/**
 * @hidden
 */
export let ListPanelItemModelDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelItemModelDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelItemModelDescriptionMetadata.a == null) {
                ListPanelItemModelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelItemModelDescriptionMetadata.c(ListPanelItemModelDescriptionMetadata.a);
            }
            if (a.k(ListPanelItemModelDescriptionMetadata.a)) {
                return;
            }
            a.aa(ListPanelItemModelDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DataRow", "Number:int");
            a.item("RowHeight", "Number:double");
            a.item("RowObjectRef", "(w:RowObject,wf:RowObject)DataRef");
            a.item("IsModelDirty", "Boolean");
        }
        static d(a) {
            ListPanelItemModelDescriptionMetadata.b(a);
            a.ac("ListPanelItemModel", () => new ListPanelItemModelDescription());
            a.ab("ListPanelItemModel", ListPanelItemModelDescriptionMetadata.a);
        }
    }
    ListPanelItemModelDescriptionMetadata.$t = /*@__PURE__*/ markType(ListPanelItemModelDescriptionMetadata, 'ListPanelItemModelDescriptionMetadata');
    ListPanelItemModelDescriptionMetadata.a = null;
    return ListPanelItemModelDescriptionMetadata;
})();
